'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.plugins = undefined;

var _styles2 = require('./styles');

var _styles = _interopRequireWildcard(_styles2);

var _selection2 = require('./selection');

var _selection = _interopRequireWildcard(_selection2);

var _expandable2 = require('./expandable');

var _expandable = _interopRequireWildcard(_expandable2);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

var plugins = function () {

    var plugins = [_styles.plugin, _selection.plugin, _expandable.plugin];

    var initAll = function initAll(grid, state) {
        // extract props and state from initial grid
        var props = grid.props;
        // alter state by each plugin

        plugins.forEach(function (plugin) {
            if (plugin.enabled) {
                // get the new state values form plugin
                var alteredState = plugin.activate(grid, props, state);
                // preserve inital events from prior plugins or default functionality
                var mixedState = preservePriorEvents(alteredState, state);
                // return new state object to main component
                state = Object.assign(state, mixedState);
            }
        });

        // return final state
        return state;
    };

    var preservePriorEvents = function preservePriorEvents(alteredState, state) {
        var newState = Object.assign({}, alteredState);
        var prevState = Object.assign({}, state);

        var eventsToPreserve = ['onRowClick', 'onRowMouseOver', 'onRowMouseOut', 'onRowMouseDown'];

        eventsToPreserve.forEach(function (eventToPreserve) {
            if (newState[eventToPreserve]) {
                alteredState[eventToPreserve] = function (args) {
                    prevState[eventToPreserve](args);
                    newState[eventToPreserve](args);
                };
            }
        });

        // return final state with prior events preserved
        return alteredState;
    };

    return {
        initAll: initAll
    };
}();

exports.plugins = plugins;