'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
var plugin = function () {
    var name = "Selection Plugin";
    var activate = function activate(grid, props, state) {

        var prevState = Object.assign({}, state);

        if (!props.isSelectable) return {};

        var keyField = props.keyField;


        if (!keyField) {
            console.error('DIGITAL GRID - You cannot use PLUGIN ' + name + ' when you don\'t have a keyField defined.');
        }

        var isSelected = function isSelected(item) {
            return grid.state.selectedKeys.indexOf(item[keyField]) !== -1;
        };

        var _rowClassNames = function _rowClassNames(args) {
            var item = args.item;

            var classNames = prevState.rowClassNames(args);
            if (isSelected(item)) {
                // add the 'grid-selected' class to the existing ones
                classNames.push('grid-selected');
            }
            return classNames;
        };
        var onMouseOver = function onMouseOver(args) {
            var event = args.event,
                item = args.item;

            if (!isSelected(item)) {
                var tr = event.currentTarget;
                tr.classList.add('grid-selected');
            }
        };
        var onMouseOut = function onMouseOut(args) {
            var event = args.event,
                item = args.item;

            if (!isSelected(item)) {
                var tr = event.currentTarget;
                tr.classList.remove('grid-selected');
            }
        };
        var onMouseDown = function onMouseDown(args) {
            var event = args.event;

            if (event.ctrlKey || event.shiftKey) {
                event.preventDefault();
            }
        };

        return {
            selectedKeys: [],
            selectedItems: [],
            selectedLast: null,
            onRowClick: function onRowClick(args) {
                return _onRowClick(args);
            },
            onRowMouseOver: function onRowMouseOver(args) {
                return onMouseOver(args);
            },
            onRowMouseOut: function onRowMouseOut(args) {
                return onMouseOut(args);
            },
            onRowMouseDown: function onRowMouseDown(args) {
                return onMouseDown(args);
            },
            rowClassNames: function rowClassNames(args) {
                return _rowClassNames(args);
            }
        };
    };

    var _onRowClick = function _onRowClick(args) {
        var event = args.event,
            item = args.item,
            grid = args.grid;
        var keyField = grid.props.keyField;

        var key = keyField ? item[keyField] : 0;

        var selectionResult = toggleSelectRow(event, key, grid.props, grid.state);
        grid.setState(selectionResult);

        if (grid.props.onSelectionChange) grid.props.onSelectionChange(selectionResult.selectedKeys, selectionResult.selectedItems, selectionResult.selectedLast);
    };

    function toggleSelectRow(event, key, props, state) {
        var isCtrl = event.ctrlKey;
        var isShift = event.shiftKey;

        if (isCtrl || isShift) {
            event.preventDefault(); // this works everywhere, except IE
            document.getSelection().removeAllRanges(); // hack for IE
        }

        var newSelectedKeys = [];
        var newSelectedItems = [];

        // keep existing values if Ctrl is pressed
        if (isCtrl) {
            newSelectedKeys = state.selectedKeys.slice();
            newSelectedItems = state.selectedItems.slice();
        }

        var keyStart = key;
        var keyEnd = key;

        if (isShift) {
            var currentKeys = [];
            props.data.forEach(function (item) {
                currentKeys.push(item[props.keyField]);
            });
            var posStart = currentKeys.indexOf(state.selectedLast);
            var posEnd = currentKeys.indexOf(keyStart);

            if (posStart < posEnd) {
                keyStart = state.selectedLast;
            } else {
                keyEnd = state.selectedLast;
            }
        }

        var update = false;
        props.data.forEach(function (item) {
            if (item[props.keyField] === keyStart) update = true;

            if (update) {
                if (newSelectedKeys.indexOf(item[props.keyField]) === -1) {
                    newSelectedKeys.push(item[props.keyField]);
                    newSelectedItems.push(item);
                } else {
                    newSelectedKeys = newSelectedKeys.filter(function (key) {
                        return key !== item[props.keyField];
                    });
                    if (props.keyField) {
                        newSelectedItems = newSelectedItems.filter(function (selItem) {
                            return selItem[props.keyField] !== item.key;
                        });
                    }
                }
            }

            if (item[props.keyField] === keyEnd) {
                update = false;
            }
        });

        return {
            selectedKeys: newSelectedKeys,
            selectedItems: newSelectedItems,
            selectedLast: key
        };
    };

    return {
        name: name,
        enabled: true,
        activate: activate
    };
}();

exports.plugin = plugin;